@@ -22,6 +22,8 @@
 void gimp_init (int, char **);
 void app_init (void);
 void app_exit (int);
+void app_exit_finish (void);
+int app_exit_finish_done (void);
 void app_init_update_status(char *label1val, char *label2val, float pct_progress);
 
 #endif /* APP_PROCS_H */
