@@ -29,6 +29,8 @@
 #define MAXIMUM(x,y) ((x > y) ? x : y)
 
 extern int no_interface;
+extern int no_splash;
+extern int no_splash_image;
 extern int no_data;
 extern int be_verbose;
 
