@@ -26,6 +26,7 @@
 #include "gdisplay.h"
 #include "gimage_mask.h"
 #include "rect_select.h"
+#include "interface.h"
 
 #define BEZIER_START     1
 #define BEZIER_ADD       2
@@ -171,8 +172,7 @@ bezier_select_load (void        *gdisp_ptr,
   gdisp = (GDisplay *) gdisp_ptr;
 
   /*  select the bezier tool  */
-  tools_select (BEZIER_SELECT);
-
+  gtk_widget_activate (tool_widgets[tool_info[BEZIER_SELECT].toolbar_position]);
   tool = active_tool;
   tool->state = ACTIVE;
   tool->gdisp_ptr = gdisp_ptr;
