@@ -62,9 +62,11 @@ static gint         brush_compare_func     (gpointer, gpointer);
 
 /*  function declarations  */
 void
-brushes_init ()
+brushes_init (int no_data)
 {
   GSList * list;
+  GBrushP gb_start = NULL;
+  gint gb_count = 0;
 
   if (brush_list)
     brushes_free();
@@ -74,7 +76,7 @@ brushes_init ()
 
   if (!brush_path)
     create_default_brush ();
-  else
+  if(!no_data)
     datafiles_read_directories (brush_path, load_brush, 0);
 
   /*  assign indexes to the loaded brushes  */
@@ -83,9 +85,39 @@ brushes_init ()
 
   while (list) {
     /*  Set the brush index  */
-    ((GBrush *) list->data)->index = num_brushes++;
-    list = g_slist_next (list);
-  }
+    /* ALT make names unique */
+    GBrushP gb = (GBrushP)list->data;
+    gb->index = num_brushes++;
+    list = g_slist_next(list);
+    if(list) {
+      GBrushP gb2 = (GBrushP)list->data;
+      
+      if(gb_start == NULL) {
+        gb_start = gb;
+      }
+      
+      if(gb_start->name
+	 && gb2->name
+	 && (strcmp(gb_start->name,gb2->name) == 0)) {
+	
+        gint b_digits = 2;
+        gint gb_tmp_cnt = gb_count++;
+	
+        /* Alter gb2... */
+        g_free(gb2->name);
+        while((gb_tmp_cnt /= 10) > 0)
+          b_digits++;
+        /* name str + " #" + digits + null */
+        gb2->name = g_malloc(strlen(gb_start->name)+3+b_digits);
+        sprintf(gb2->name,"%s #%d",gb_start->name,gb_count);
+      }
+      else
+      {
+        gb_start = gb2;
+        gb_count = 0;
+      }
+    }  
+  }                  
 }
 
 
@@ -161,7 +193,7 @@ create_default_brush ()
 
   brush->filename = NULL;
   brush->name = g_strdup ("Default");
-  brush->mask = temp_buf_new (1, 1, 1, 0, 0, filled);
+  brush->mask = temp_buf_new (1, 1, 1, 0, 0, (unsigned char *)filled);
   brush->spacing = 25;
 
   /*  Swap the brush to disk (if we're being stingy with memory) */
@@ -437,7 +469,7 @@ brushes_refresh_brush_invoker (Argument *args)
    */
 
   success = TRUE ;
-  brushes_init();
+  brushes_init(TRUE);
   return procedural_db_return_args (&brushes_refresh_brush_proc, success);
 }
 
