@@ -26,23 +26,25 @@
 #include "errors.h"
 #include "gimage_mask.h"
 #include "layer.h"
-#include "linked.h"
 #include "paint_funcs.h"
 #include "temp_buf.h"
 #include "undo.h"
 
 #include "channel_pvt.h"
 
+/*
 enum {
   LAST_SIGNAL
 };
-
+*/
 
 static void gimp_channel_class_init (GimpChannelClass *klass);
 static void gimp_channel_init       (GimpChannel      *channel);
 static void gimp_channel_destroy    (GtkObject        *object);
 
+/*
 static gint channel_signals[LAST_SIGNAL] = { 0 };
+*/
 
 static GimpDrawableClass *parent_class = NULL;
 
@@ -78,7 +80,9 @@ gimp_channel_class_init (GimpChannelClass *class)
   object_class = (GtkObjectClass*) class;
   parent_class = gtk_type_class (gimp_drawable_get_type ());
 
+  /*
   gtk_object_class_add_signals (object_class, channel_signals, LAST_SIGNAL);
+  */
 
   object_class->destroy = gimp_channel_destroy;
 }
@@ -144,6 +148,21 @@ channel_new (int gimage_ID, int width, int height, char *name, int opacity,
   return channel;
 }
 
+Channel *
+channel_ref (Channel *channel)
+{
+  gtk_object_ref  (GTK_OBJECT (channel));
+  gtk_object_sink (GTK_OBJECT (channel));
+  return channel;
+}
+
+
+void
+channel_unref (Channel *channel)
+{
+  gtk_object_unref (GTK_OBJECT (channel));
+}
+
 
 Channel *
 channel_copy (Channel *channel)
@@ -193,7 +212,7 @@ channel_get_ID (int ID)
 void
 channel_delete (Channel *channel)
 {
-  gtk_object_destroy (GTK_OBJECT (channel));
+  gtk_object_unref (GTK_OBJECT (channel));
 }
 
 static void
@@ -412,7 +431,7 @@ channel_preview (Channel *channel, int width, int height)
 void
 channel_invalidate_previews (int gimage_id)
 {
-  link_ptr tmp;
+  GSList * tmp;
   Channel * channel;
   GImage * gimage;
 
@@ -425,7 +444,7 @@ channel_invalidate_previews (int gimage_id)
     {
       channel = (Channel *) tmp->data;
       drawable_invalidate_preview (GIMP_DRAWABLE(channel));
-      tmp = next_item (tmp);
+      tmp = g_slist_next (tmp);
     }
 }
 
