@@ -1261,14 +1261,18 @@ file_pref_cmd_callback (GtkWidget *widget,
                           &allow_resize_windows);
       gtk_widget_show (button);
       
-      button = gtk_check_button_new_with_label("Auto save");
-      gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button),
+      /* Don't show the Auto-save button until we really 
+	 have auto-saving in the gimp.
+      
+	 button = gtk_check_button_new_with_label("Auto save");
+	 gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button),
                                    auto_save);
-      gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-      gtk_signal_connect (GTK_OBJECT (button), "toggled",
-                          (GtkSignalFunc) file_prefs_toggle_callback,
-                          &auto_save);
-      gtk_widget_show (button);
+	 gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	 gtk_signal_connect (GTK_OBJECT (button), "toggled",
+	                           (GtkSignalFunc) file_prefs_toggle_callback,
+                                   &auto_save);
+         gtk_widget_show (button);
+      */
 
       button = gtk_check_button_new_with_label("Disable cursor updating");
       gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button),
@@ -1652,7 +1656,7 @@ select_border_cmd_callback (GtkWidget *widget,
 
   sprintf (initial, "%d", gimage_mask_border_radius);
   query_string_box ("Border Selection", "Border selection by:", initial,
-		    gimage_mask_border_callback, gdisp->gimage);
+		    gimage_mask_border_callback, (gpointer) gdisp->gimage->ID);
 }
 
 void
@@ -1666,7 +1670,7 @@ select_feather_cmd_callback (GtkWidget *widget,
 
   sprintf (initial, "%f", gimage_mask_feather_radius);
   query_string_box ("Feather Selection", "Feather selection by:", initial,
-		    gimage_mask_feather_callback, gdisp->gimage);
+		    gimage_mask_feather_callback, (gpointer) gdisp->gimage->ID);
 }
 
 void
@@ -1680,7 +1684,7 @@ select_grow_cmd_callback (GtkWidget *widget,
 
   sprintf (initial, "%d", gimage_mask_grow_pixels);
   query_string_box ("Grow Selection", "Grow selection by:", initial,
-		    gimage_mask_grow_callback, gdisp->gimage);
+		    gimage_mask_grow_callback, (gpointer) gdisp->gimage->ID);
 }
 
 void
@@ -1694,7 +1698,7 @@ select_shrink_cmd_callback (GtkWidget *widget,
 
   sprintf (initial, "%d", gimage_mask_shrink_pixels);
   query_string_box ("Shrink Selection", "Shrink selection by:", initial,
-		    gimage_mask_shrink_callback, gdisp->gimage);
+		    gimage_mask_shrink_callback, (gpointer) gdisp->gimage->ID);
 }
 
 void
@@ -2482,7 +2486,9 @@ gimage_mask_feather_callback (GtkWidget *w,
   GImage *gimage;
   double feather_radius;
 
-  gimage = (GImage *) client_data;
+  if (!(gimage = gimage_get_ID ((int)client_data)))
+    return;
+
   feather_radius = atof (call_data);
 
   gimage_mask_feather (gimage, feather_radius);
@@ -2498,7 +2504,9 @@ gimage_mask_border_callback (GtkWidget *w,
   GImage *gimage;
   int border_radius;
 
-  gimage = (GImage *) client_data;
+  if (!(gimage = gimage_get_ID ((int)client_data)))
+    return;
+
   border_radius = atoi (call_data);
 
   gimage_mask_border (gimage, border_radius);
@@ -2514,7 +2522,9 @@ gimage_mask_grow_callback (GtkWidget *w,
   GImage *gimage;
   int grow_pixels;
 
-  gimage = (GImage *) client_data;
+  if (!(gimage = gimage_get_ID ((int)client_data)))
+    return;
+
   grow_pixels = atoi (call_data);
 
   gimage_mask_grow (gimage, grow_pixels);
@@ -2530,9 +2540,17 @@ gimage_mask_shrink_callback (GtkWidget *w,
   GImage *gimage;
   int shrink_pixels;
 
-  gimage = (GImage *) client_data;
+  if (!(gimage = gimage_get_ID ((int)client_data)))
+    return;
+
   shrink_pixels = atoi (call_data);
 
   gimage_mask_shrink (gimage, shrink_pixels);
   gdisplays_flush ();
 }
+
+
+
+
+
+
