@@ -19,18 +19,18 @@
   /*
    * TODO for Convert:
    *
-   *   Make GRAYSCALE->INDEXED sane again (done?)
-   *
    *   Use palette of another open INDEXED image
    *
-   * Post-1.0 TODO:
-   *
    *   Different dither types
    *
    *   Alpha dithering
    */
 
 /*
+ * 98/03/23 - fixed a longstanding fencepost - hopefully the *right*
+ *  way, *again*.  (anyone ELSE want a go?  okay, just kidding... :))
+ *  [Adam]
+ *
  * 97/11/14 - added a proper pdb interface and support for dithering
  *  to custom palettes (based on a patch by Eric Hernes) [Yosh]
  *
@@ -54,6 +54,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+
 #include "appenv.h"
 #include "actionarea.h"
 #include "convert.h"
@@ -194,6 +195,7 @@ typedef struct
   GtkWidget *  shell;
   void *       gimage_ptr;
 
+  int          gimage_ID;
   int          dither;
   int          num_cols;
   int          palette;
@@ -279,6 +281,7 @@ convert_to_indexed (void *gimage_ptr)
   gimage = (GImage *) gimage_ptr;
   dialog = (IndexedDialog *) g_malloc (sizeof (IndexedDialog));
   dialog->gimage_ptr = gimage_ptr;
+  dialog->gimage_ID = gimage->ID;
   dialog->num_cols = 256;
   dialog->dither = TRUE;
 
@@ -466,7 +469,7 @@ build_palette_menu(int *default_palette){
 
   if(!palette_entries_list) {
     /* fprintf(stderr, "no palette_entries_list, building...\n");*/
-     palette_init_palettes();
+     palette_init_palettes(FALSE);
   }
 
   list = palette_entries_list;
@@ -524,8 +527,12 @@ indexed_ok_callback (GtkWidget *widget,
         else
           palette_type = REUSE_PALETTE;
   /*  Convert the image to indexed color  */
-  convert_image ((GImage *) dialog->gimage_ptr, INDEXED, dialog->num_cols, dialog->dither, palette_type);
-  gdisplays_flush ();
+  if (gimage_get_ID (dialog->gimage_ID))
+    {
+      convert_image ((GImage *) dialog->gimage_ptr, INDEXED, dialog->num_cols,
+		     dialog->dither, palette_type);
+      gdisplays_flush ();
+    }
 
   gtk_widget_destroy (dialog->shell);
   g_free (dialog);
@@ -1007,7 +1014,10 @@ generate_histogram_rgb (Histogram  histogram,
 
   g_print ("col_limit = %d, nfc = %d\n", col_limit, num_found_cols);
 
-  pixel_region_init (&srcPR, GIMP_DRAWABLE(layer)->tiles, 0, 0, GIMP_DRAWABLE(layer)->width, GIMP_DRAWABLE(layer)->height, FALSE);
+  pixel_region_init (&srcPR, GIMP_DRAWABLE(layer)->tiles, 0, 0,
+		     GIMP_DRAWABLE(layer)->width,
+		     GIMP_DRAWABLE(layer)->height,
+		     FALSE);
   for (pr = pixel_regions_register (1, &srcPR);
        pr != NULL;
        pr = pixel_regions_process (pr))
@@ -1060,8 +1070,8 @@ generate_histogram_rgb (Histogram  histogram,
 		       * existing colours
 		       */
 		      
-		      /* Remember the new colour we just found.
-		       */
+		      num_found_cols++;
+		      
 		      if (num_found_cols > col_limit)
 			{
 			  /* There are more colours in the image
@@ -1070,16 +1080,17 @@ generate_histogram_rgb (Histogram  histogram,
 			   *  quantizing at a later stage.
 			   */
 			  needs_quantize = TRUE;
-			  g_print ("max colours exceeded - needs quantize.\n");
+			  g_print ("\nmax colours exceeded - needs quantize.\n");
 			  goto already_found;
 			}
-
-		      found_cols[num_found_cols][0] = data[RED_PIX];
-		      found_cols[num_found_cols][1] = data[GREEN_PIX];
-		      found_cols[num_found_cols][2] = data[BLUE_PIX];
-		      
-		      num_found_cols++;
-		      
+		      else
+			{
+			  /* Remember the new colour we just found.
+			   */
+			  found_cols[num_found_cols-1][0] = data[RED_PIX];
+			  found_cols[num_found_cols-1][1] = data[GREEN_PIX];
+			  found_cols[num_found_cols-1][2] = data[BLUE_PIX];
+			}
 		    }
 		}
 	    already_found:
@@ -3057,7 +3068,7 @@ convert_indexed_palette_invoker (Argument *args)
 		  case CUSTOM_PALETTE:
           palette_name = args[4].value.pdb_pointer;
  /*         fprintf(stderr, "looking for palette `%s'\n", palette_name); */
-          if (!palette_entries_list) palette_init_palettes();
+          if (!palette_entries_list) palette_init_palettes(FALSE);
 		    for(list = palette_entries_list;
               list;
               list = g_slist_next(list)) {
