@@ -488,6 +488,7 @@ file_open_callback (GtkWidget *w,
       if (GTK_WIDGET_VISIBLE (fileload))
 	return;
 
+      gtk_file_selection_set_filename (GTK_FILE_SELECTION(fileload), ".");
       gtk_window_set_title (GTK_WINDOW (fileload), "Load Image");
     }
 
@@ -562,7 +563,7 @@ file_save_as_callback (GtkWidget *w,
       filesave = gtk_file_selection_new ("Save Image");
       gtk_window_set_wmclass (GTK_WINDOW (filesave), "save_image", "Gimp");
       gtk_window_position (GTK_WINDOW (filesave), GTK_WIN_POS_MOUSE);
-      gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesave)->cancel_button),
+      gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesave)->cancel_button),
 			  "clicked",
 			  GTK_SIGNAL_FUNC (file_dialog_hide),
 			  GTK_OBJECT (filesave));
@@ -578,6 +579,7 @@ file_save_as_callback (GtkWidget *w,
       if (GTK_WIDGET_VISIBLE (filesave))
 	return;
 
+      gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesave), ".");
       gtk_window_set_title (GTK_WINDOW (filesave), "Save Image");
     }
 
@@ -762,6 +764,8 @@ file_save (int   image_ID,
 
   if ((gimage = gimage_get_ID (image_ID)) == NULL)
     return FALSE;
+  if (gimage_active_drawable (gimage) == NULL)
+    return FALSE;
 
   file_proc = save_file_proc;
   if (!file_proc)
@@ -898,6 +902,8 @@ file_save_ok_callback (GtkWidget *w,
     {
       s = g_string_new ("Save failed: ");
       g_string_append (s, raw_filename);
+      g_string_append (s, "\nYou might have tried to save an RGB image with");
+      g_string_append (s, "\na plug-in that only supports Indexed or Gray images");
     }
 
   message_box (s->str, NULL, NULL);
@@ -950,7 +956,7 @@ file_overwrite (char *filename, char* raw_filename)
   overwrite_box->full_filename = filename;
   overwrite_box->raw_filename = raw_filename;
   overwrite_box->obox = gtk_dialog_new ();
-  gtk_window_set_wmclass (GTK_WINDOW (overwrite_box->obox), "fiel_exists", "Gimp");
+  gtk_window_set_wmclass (GTK_WINDOW (overwrite_box->obox), "file_exists", "Gimp");
   gtk_window_set_title (GTK_WINDOW (overwrite_box->obox), "File Exists!");
   gtk_window_position (GTK_WINDOW (overwrite_box->obox), GTK_WIN_POS_MOUSE);
 
@@ -999,6 +1005,8 @@ file_overwrite_yes_callback (GtkWidget *w,
       s = g_string_new ("Save failed: ");
 
       g_string_append (s, overwrite_box->raw_filename);
+      g_string_append (s, "\nYou might have tried to save an RGB image with");
+      g_string_append (s, "\na plug-in that only supports Indexed or Gray images");
 
       message_box (s->str, NULL, NULL);
 
@@ -1158,7 +1166,7 @@ static void file_convert_string (char *instr,
                   break;
               }
             *tmpptr = '\0';
-            sscanf (tmp, "%o", &k);
+            sscanf ((char *)tmp, "%o", &k);
             *(uout++) = k;
             break;
 
