@@ -227,9 +227,9 @@ tools_button_press (GtkWidget      *w,
 static gint
 toolbox_delete (GtkWidget *w, GdkEvent *e, gpointer data)
 {
-  app_exit (FALSE);
+  app_exit (0);
 
-  return FALSE;
+  return TRUE;
 }
 
 static void
@@ -252,7 +252,7 @@ gdisplay_delete (GtkWidget *w,
 {
   gdisplay_close_window (gdisp, FALSE);
 
-  return FALSE;
+  return TRUE;
 }
 
 static void
@@ -820,7 +820,7 @@ query_box_delete_callback (GtkWidget *w,
 {
   query_box_cancel_callback (w, client_data);
 
-  return FALSE;
+  return TRUE;
 }
 
 static void
@@ -957,7 +957,7 @@ message_box_delete_callback (GtkWidget *w, GdkEvent *e, gpointer client_data)
 {
   message_box_close_callback (w, client_data);
 
-  return FALSE;
+  return TRUE;
 }
 
 
