@@ -39,6 +39,13 @@
 #include "temp_buf.h"
 #include "tools.h"
 
+#ifndef M_PI
+#define M_PI    3.14159265358979323846
+#endif /* M_PI */
+#ifndef M_PI_4
+#define M_PI_4  0.78539816339744830962
+#endif /* M_PI_4 */
+
 /*  local structures  */
 
 typedef struct _IScissorsOptions IScissorsOptions;
@@ -274,10 +281,9 @@ selection_to_bezier(GtkWidget *w, gpointer none)
 	iscissors = (Iscissors *) last_tool->private;
 	last_tool->state = INACTIVE;
 	bezierify_boundary (last_tool);
-	tools_select(BEZIER_SELECT);
     }
    return;
-};
+}
 
 static IScissorsOptions *
 iscissors_selection_options (void)
@@ -451,6 +457,7 @@ tools_new_iscissors ()
   tool->arrow_keys_func = standard_arrow_keys_func;
   tool->cursor_update_func = rect_select_cursor_update;
   tool->control_func = iscissors_control;
+  tool->auto_snap_to = 0;
   
   last_tool = tool;
   
@@ -545,8 +552,8 @@ iscissors_button_press (Tool           *tool,
 				  drawable_height(drawable));
 				  
       iscissors->num_segs = 0;
-	x = iscissors->x;
-	y = iscissors->y;
+	x = bevent->x;
+	y = bevent->y;
 	
       add_segment (&(iscissors->num_segs), x, y);
 
@@ -633,7 +640,6 @@ iscissors_button_release (Tool           *tool,
 	  /*  Add one additional segment  */
 	  add_segment (&(iscissors->num_segs), segs[0].x1, segs[0].y1);
 
-
 	  if (iscissors->num_segs >= 3)
 	    {
 	      /*  Find the boundary  */
@@ -672,9 +678,6 @@ iscissors_motion (Tool           *tool,
   gdisp = (GDisplay *) gdisp_ptr;
   iscissors = (Iscissors *) tool->private;
 
-  gdisplay_untransform_coords (gdisp, mevent->x, mevent->y,
-			       &iscissors->x, &iscissors->y, FALSE, TRUE); 
-
   
   switch (iscissors->state)
     {
@@ -745,6 +748,9 @@ iscissors_draw_CR (GDisplay  *gdisp,
   int index;
   int i;
 
+  GimpDrawable *drawable;
+  drawable = gimage_active_drawable (gdisp->gimage);
+
   /* construct the geometry matrix from the segment */
   /* assumes that a valid segment containing 4 points is passed in */
 
@@ -761,16 +767,8 @@ iscissors_draw_CR (GDisplay  *gdisp,
 	  geometry[i][1] = pts[indices[i]].dy * SUPERSAMPLE;
 	  break;
 	case SCREEN_COORDS:
-/*	  gdisplay_transform_coords_f (gdisp, , &x, &y, TRUE);
-      gdisplay_transform_coords (gdisp, points->x, points->y,
-				 &points->sx, &points->sy, 0);
-     
-*/
-/*
-      gdisplay_untransform_coords_f (gdisp, (int) pts[indices[i]].dx, (int) pts[indices[i]].dy,
-			   &x, &y, TRUE); 
-
-*/
+	  gdisplay_transform_coords_f(gdisp, (int) pts[indices[i]].dx, 
+			  (int) pts[indices[i]].dy, &x, &y, TRUE);
 	  geometry[i][0] = x;
 	  geometry[i][1] = y;
 	  /*g_print("%f %f\n", x, y);*/
@@ -840,9 +838,13 @@ iscissors_draw_CR (GDisplay  *gdisp,
 	{
 	  /* add the point to the point buffer */
 		      	  
-	  gdisplay_transform_coords (gdisp, newx, newy, &tx, &ty,1 );
-	  gdk_points[index].x = tx;
-	  gdk_points[index].y = ty;
+	  /*gdisplay_transform_coords (gdisp, newx, newy, &tx, &ty,1 );*/
+	  /*drawable_offsets(drawable, &tx, &ty);
+	  tx += newx;
+	  ty += newy;*/
+	  
+	  gdk_points[index].x = newx;
+	  gdk_points[index].y = newy;
 
 
 	  index++;
@@ -974,6 +976,7 @@ add_segment (int *num_segs,
   return 1;
 }
 
+
 static int
 add_point (int    *num_pts,
 	   int     kink,
@@ -1247,6 +1250,7 @@ find_edge_xy (TempBuf *edge_buf,
 static void
 find_boundary (Tool *tool)
 {
+  
   /*  Find directional changes  */
   shape_of_boundary (tool);
 
@@ -1312,13 +1316,19 @@ shape_of_boundary (Tool *tool)
 
   for (i = 0,j=0; i < iscissors->num_kinks; i++)
     {
+	/* untransform coords */
+     gdisplay_untransform_coords (gdisp, segs[i].x1, segs[i].y1,
+		       &kinks[j].x, &kinks[j].y, FALSE, TRUE);
+	    
+/*	   
       kinks[j].x = segs[i].x1;
       kinks[j].y = segs[i].y1;
+*/
       
 	if(j) {
-	   if((kinks[i].x != kinks[j-1].x) || (kinks[j].y != kinks[j-1].y))
+	   if((kinks[j].x != kinks[j-1].x) || (kinks[j].y != kinks[j-1].y))
 		++j;
-	} else ++j;
+	} else j++;
     }
 
   iscissors->num_kinks = j;
@@ -1883,10 +1893,16 @@ calculate_edge_map (GImage *gimage,
   pixel_region_init(&srcPR, drawable_data(drawable), x1, y1, width, height, 1);
 
   /*  Get the horizontal derivative  */
-  destPR.data = conv1 + MAX_CHANNELS * (CONV_WIDTH * offy + offx);
+  destPR.data = conv1 /*+ MAX_CHANNELS * (CONV_WIDTH * offy + offx)*/;
   destPR.rowstride = CONV_WIDTH * MAX_CHANNELS;
   destPR.tiles = NULL;
-
+  destPR.bytes = MAX_CHANNELS;
+  destPR.x = x1;
+  destPR.y = y1;
+  destPR.w = CONV_WIDTH;
+  destPR.h = CONV_HEIGHT;
+  destPR.dirty = 1;
+  
   for (pr =pixel_regions_register (2, &srcPR, &destPR); pr != NULL; pr = pixel_regions_process (pr))
     gaussian_deriv (&srcPR, &destPR, HORIZONTAL, std_dev);
 
@@ -2005,8 +2021,8 @@ construct_edge_map (Tool    *tool,
   /*  init some variables  */
   srcPR.bytes = edge_buf->bytes;
   destPR.rowstride = edge_buf->bytes * edge_buf->width;
-  destPR.x = edge_buf->x;
-  destPR.y = edge_buf->y;
+  destPR.x = 0 /*edge_buf->x*/;
+  destPR.y = 0 /*edge_buf->y*/;
   destPR.h = edge_buf->height;
   destPR.w = edge_buf->width;
   destPR.bytes = edge_buf->bytes;
@@ -2088,7 +2104,7 @@ construct_edge_map (Tool    *tool,
     }
     
 #ifdef ISCISSORS_STILL_DOES_NOT_WORK
-
+    
   /*  dump the edge buffer for debugging*/
 
    dump=fopen("dump", "w"); 
@@ -2520,9 +2536,12 @@ CR_convert (Iscissors *iscissors,
   int *vals, val;
   int x, w;
   int i, j;
+  int offx, offy;
   PixelRegion maskPR;
   unsigned char *buf, *b;
-
+  GimpDrawable *drawable;
+  
+  drawable = gimage_active_drawable(gdisp->gimage);
   vals = NULL;
 
   /* destroy previous region */
@@ -2574,11 +2593,12 @@ CR_convert (Iscissors *iscissors,
       iscissors_draw_CR (gdisp, iscissors, pts, indices, draw_type);
     }
 
+  drawable_offsets(drawable, &offx, &offy);
   pixel_region_init (&maskPR, iscissors->mask->drawable.tiles, 0, 0,
 		     iscissors->mask->drawable.width,
 		     iscissors->mask->drawable.height, TRUE);
 
-  for (i = 0; i < height; i++)
+  for (i = 0; i < height-(offy*SUPERSAMPLE); i++)
     {
       list = CR_scanlines[i];
 
@@ -2588,7 +2608,7 @@ CR_convert (Iscissors *iscissors,
 
       while (list)
         {
-          x = (long) list->data;
+          x = (long) list->data + offx;
           if ( x < 0 ) x = 0;
           
           list = list->next;
@@ -2599,7 +2619,7 @@ CR_convert (Iscissors *iscissors,
 		  if (w+x > width) w = width - x;
 		  
 	      if (!antialias)
-		 channel_add_segment (iscissors->mask, x, i, w, 255);
+		 channel_add_segment (iscissors->mask, x, i+offy, w, 255);
 	      else
 		for (j = 0; j < w; j++)
 		  vals[j + x] += 255;
@@ -2619,7 +2639,7 @@ CR_convert (Iscissors *iscissors,
 
 	      *b++ = (unsigned char) (val / SUPERSAMPLE2);
 	    }
-	  pixel_region_set_row (&maskPR, 0, (i / SUPERSAMPLE), iscissors->mask->drawable.width, buf);
+	  pixel_region_set_row (&maskPR, offx/*0*/, (i / SUPERSAMPLE)+offy, iscissors->mask->drawable.width-offx, buf);
 	}
 
       g_slist_free (CR_scanlines[i]);
