@@ -16,6 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include "config.h"
+#include <locale.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -78,12 +79,14 @@ main (int argc, char **argv)
   int i, j;
   gchar *display_name, *display_env;
 
-  atexit (g_mem_profile);
+  ATEXIT (g_mem_profile);
 
   /* Initialize variables */
   prog_name = argv[0];
 
   /* Initialize Gtk toolkit */
+  gtk_set_locale ();
+  setlocale(LC_NUMERIC, "C");  /* must use dot, not comma, as decimal separator */
   gtk_init (&argc, &argv);
   gtk_accelerator_table_set_mod_mask (NULL, GDK_SHIFT_MASK |
                                             GDK_CONTROL_MASK |
@@ -183,11 +186,7 @@ main (int argc, char **argv)
       g_print ("  --no-shm               Do not use shared memory between GIMP and its plugins.\n");
       g_print ("  --no-xshm              Do not use the X Shared Memory extension.\n");
       g_print ("  --display <display>    Use the designated X display.\n\n");
-      g_print ("Valid debugging options are:\n");
-      g_print ("  --sync                 Send X commands synchronously.\n");
-      g_print ("  --show-events          Show GDK events.\n");
-      g_print ("  --no-show-events       Don't show GDK events.\n");
-      g_print ("  --debug-level <level>  Provide debug output at designated level.\n");
+
     }
 
   if (show_version || show_help)
