@@ -86,6 +86,7 @@ static gint palette_color_area_events (GtkWidget *, GdkEvent *, PaletteP);
 static void palette_scroll_update (GtkAdjustment *, gpointer);
 static void palette_new_callback (GtkWidget *, gpointer);
 static void palette_delete_callback (GtkWidget *, gpointer);
+static void palette_refresh_callback (GtkWidget *, gpointer);
 static void palette_edit_callback (GtkWidget *, gpointer);
 static void palette_close_callback (GtkWidget *, gpointer);
 static gint palette_dialog_delete_callback (GtkWidget *, GdkEvent *, gpointer);
@@ -107,6 +108,9 @@ static int              num_palette_entries = 0;
 static unsigned char    foreground[3] = { 0, 0, 0 };
 static unsigned char    background[3] = { 255, 255, 255 };
 
+/*  Color select dialog  */
+static ColorSelectP color_select = NULL;
+static int color_select_active = 0;
 
 static ActionAreaItem action_items[] =
 {
@@ -119,16 +123,16 @@ static ActionAreaItem action_items[] =
 static MenuItem palette_ops[] =
 {
   { "New Palette", 0, 0, palette_new_entries_callback, NULL, NULL, NULL },
-  { "Merge Palette", 0, 0, palette_merge_entries_callback, NULL, NULL, NULL },
   { "Delete Palette", 0, 0, palette_delete_entries_callback, NULL, NULL, NULL },
+  { "Refresh Pallettes", 0, 0, palette_refresh_callback, NULL, NULL, NULL },
   { "Close", 0, 0, palette_close_callback, NULL, NULL, NULL },
   { NULL, 0, 0, NULL, NULL, NULL, NULL },
 };
 
 void
-palettes_init ()
+palettes_init (int no_data)
 {
-  palette_init_palettes ();
+  palette_init_palettes (no_data);
 }
 
 void
@@ -150,6 +154,7 @@ palette_create ()
   GtkWidget *arrow;
   GtkWidget *menu_bar;
   GtkWidget *menu_bar_item;
+  int i;
 
   if (!palette)
     {
@@ -182,13 +187,9 @@ palette_create ()
       gtk_box_pack_start (GTK_BOX (vbox), options_box, FALSE, FALSE, 0);
 
       /*  The popup menu -- palette_ops  */
-      palette_ops[0].user_data = palette;
-      palette_ops[1].user_data = palette;
-      palette_ops[2].user_data = palette;
-      palette_ops[3].user_data = palette;
-      palette_ops[4].user_data = palette;
-      palette_ops[5].user_data = palette;
-      palette_ops[6].user_data = palette;
+      for (i = 0; palette_ops[i].label; i++)
+	  palette_ops[i].user_data = palette;
+
       palette->palette_ops = build_menu (palette_ops, NULL);
 
       /*  The palette commands pulldown menu  */
@@ -255,6 +256,9 @@ palette_create ()
       gtk_widget_show (frame);
       gtk_widget_show (hbox);
 
+      if(no_data)
+	 palettes_init(FALSE);
+
       /*  The action area  */
       action_items[0].user_data = palette;
       action_items[1].user_data = palette;
@@ -379,9 +383,11 @@ palette_swap_colors (void)
 }
 
 void
-palette_init_palettes (void)
+palette_init_palettes (int no_data)
 {
-  datafiles_read_directories (palette_path, palette_entries_load, 0);
+  if(!no_data)
+    datafiles_read_directories (palette_path, palette_entries_load, 0);
+
 }
 
 
@@ -754,18 +760,18 @@ palette_color_area_events (GtkWidget *widget,
     {
     case GDK_BUTTON_PRESS:
       bevent = (GdkEventButton *) event;
-
+      width = palette->color_area->requisition.width;
+      height = palette->color_area->requisition.height;
+      entry_width = ((width - (SPACING * (COLUMNS + 1))) / COLUMNS) + SPACING;
+      entry_height = ((height - (SPACING * (ROWS + 1))) / ROWS) + SPACING;
+      
+      col = (bevent->x - 1) / entry_width;
+      row = (palette->scroll_offset + bevent->y - 1) / entry_height;
+      pos = row * COLUMNS + col;
+      
       if (bevent->button == 1 && palette->entries)
 	{
-	  width = palette->color_area->requisition.width;
-	  height = palette->color_area->requisition.height;
-	  entry_width = ((width - (SPACING * (COLUMNS + 1))) / COLUMNS) + SPACING;
-	  entry_height = ((height - (SPACING * (ROWS + 1))) / ROWS) + SPACING;
-
-	  col = (bevent->x - 1) / entry_width;
-	  row = (palette->scroll_offset + bevent->y - 1) / entry_height;
-	  pos = row * COLUMNS + col;
-
+	  
 	  tmp_link = g_slist_nth (palette->entries->colors, pos);
 	  if (tmp_link)
 	    {
@@ -785,11 +791,11 @@ palette_color_area_events (GtkWidget *widget,
 	    }
 	}
       break;
-
+      
     default:
       break;
     }
-
+  
   return FALSE;
 }
 
@@ -844,6 +850,33 @@ palette_delete_callback (GtkWidget *w,
     palette_delete_entry (palette);
 }
 
+
+static void
+palette_refresh_callback (GtkWidget *w,
+			  gpointer client_data)
+{
+  PaletteP palette;
+  
+  palette = client_data;
+  if(palette)
+    {
+      palette_free_palettes (); 
+      palette_init_palettes(FALSE);
+      palette_create_palette_menu (palette, default_palette_entries);
+      palette_calc_scrollbar (palette);
+      palette_draw_entries (palette);
+      palette_draw_current_entry (palette);
+    }
+  else
+    {
+      palette_free_palettes (); 
+      palette_init_palettes(FALSE);
+    }
+  
+}
+
+
+
 static void
 palette_edit_callback (GtkWidget *w,
 		       gpointer   client_data)
@@ -1012,7 +1045,7 @@ palette_delete_entries_callback (GtkWidget *w,
       palette->entries = NULL;
 
       palette_free_palettes ();   /*  free palettes, don't save any modified versions  */
-      palette_init_palettes ();   /*  load in brand new palettes  */
+      palette_init_palettes (FALSE);   /*  load in brand new palettes  */
 
       palette_create_palette_menu (palette, default_palette_entries);
     }
@@ -1053,7 +1086,7 @@ palette_select_callback (int   r,
 	  }
 	/* Fallthrough */
       case COLOR_SELECT_CANCEL:
-	color_select_hide (palette->color_select);
+        color_select_hide (palette->color_select);
 	palette->color_select_active = 0;
       }
     }
@@ -1432,6 +1465,51 @@ palette_calc_scrollbar (PaletteP palette)
 /****************************/
 /*  PALETTE_GET_FOREGROUND  */
 
+
+static Argument *
+palette_refresh_invoker (Argument *args)
+{
+  /* FIXME: I've hardcoded success to be 1, because brushes_init() is a 
+   *        void function right now.  It'd be nice if it returned a value at 
+   *        some future date, so we could tell if things blew up when reparsing
+   *        the list (for whatever reason). 
+   *                       - Seth "Yes, this is a kludge" Burgess
+   *                         <sjburges@ou.edu>
+   *   -and shaemlessly stolen by Adrian Likins for use here...
+   */
+  
+  int success = TRUE ;
+  palette_free_palettes();
+  palette_init_palettes(FALSE);
+
+  return procedural_db_return_args (&palette_refresh_proc, success);
+}
+
+
+ProcRecord palette_refresh_proc =
+{
+  "gimp_palette_refresh",
+  "Refreshes current palettes",
+  "This procedure incorporates all palettes currently in the users palette path. ",
+  "Adrian Likins <adrain@gimp.org>",
+  "Adrian Likins",
+  "1998",
+  PDB_INTERNAL,
+
+  /* input aarguments */
+  0,
+  NULL,
+
+  /* Output arguments */
+  0,
+  NULL,
+  
+  /* Exec mehtos  */
+  { { palette_refresh_invoker } },
+};
+
+
+
 static Argument *
 palette_get_foreground_invoker (Argument *args)
 {
