@@ -422,6 +422,9 @@ text_create_dialog (TextTool *text_tool)
   gtk_window_set_title (GTK_WINDOW (text_tool->shell), "Text Tool");
   gtk_window_set_policy (GTK_WINDOW (text_tool->shell), FALSE, TRUE, TRUE);
   gtk_window_position (GTK_WINDOW (text_tool->shell), GTK_WIN_POS_MOUSE);
+  gtk_widget_set (GTK_WIDGET (text_tool->shell),
+		  "GtkWindow::auto_shrink", FALSE,
+		  NULL);
 
   /* handle the wm close signal */
   gtk_signal_connect (GTK_OBJECT (text_tool->shell), "delete_event",
@@ -884,9 +887,11 @@ text_size_key_function (GtkWidget   *w,
 
   text_tool = (TextTool *) data;
 
-  if (event->keyval == GDK_Return)
+  if ((event->keyval == GDK_Return) || (event->keyval == GDK_Tab) ||
+        (event->keyval == GDK_space))
     {
-      gtk_signal_emit_stop_by_name (GTK_OBJECT (w), "key_press_event");
+      if (event->keyval != GDK_Tab)
+          gtk_signal_emit_stop_by_name (GTK_OBJECT (w), "key_press_event");
 
       old_value = atoi (gtk_entry_get_text (GTK_ENTRY (text_tool->size_text)));
       if (!text_load_font (text_tool))
