@@ -121,6 +121,8 @@ create_transform_options (void)
   gtk_signal_connect (GTK_OBJECT (smoothing_toggle), "toggled",
 		      (GtkSignalFunc) transform_toggle_update,
 		      &options->smoothing);
+  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (smoothing_toggle),
+                      options->smoothing);
   gtk_widget_show (smoothing_toggle);
 
 
