@@ -80,6 +80,14 @@
 #include <sys/stat.h>
 #include <time.h>		/* for seed of random number */
 
+#ifndef M_PI
+#define M_PI    3.14159265358979323846
+#endif /* M_PI */
+
+#ifndef RAND_MAX
+#define RAND_MAX 2147483647
+#endif /* RAND_MAX */
+
 #define PARAM_FILE_FORMAT_VERSION	1.0
 #define	PLUG_IN_NAME	"plug_in_CML_explorer"
 #define SHORT_NAME	"CML_explorer"
@@ -113,7 +121,7 @@ typedef struct
 
 typedef struct
 {
-  guchar *name;
+  gchar *name;
   gpointer data;
 } gtkW_menu_item;
 /* gtkW global variables */
@@ -139,16 +147,16 @@ static void	gtkW_menu_update (GtkWidget *widget, gpointer   data);
 static void	gtkW_toggle_change_value (gtkW_widget_table	*wtable);
 /* gtkW method */
 GtkWidget	*gtkW_check_button_new (GtkWidget	*parent,
-					guchar		*name,
+					gchar		*name,
 					GtkSignalFunc	update,
 					gint		*value);
-static GtkWidget	*gtkW_dialog_new (guchar	*name,
+static GtkWidget	*gtkW_dialog_new (gchar	*name,
 					  GtkSignalFunc	ok_callback,
 					  GtkSignalFunc	close_callback);
-static GtkWidget	*gtkW_frame_new (GtkWidget *parent, guchar *name);
+static GtkWidget	*gtkW_frame_new (GtkWidget *parent, gchar *name);
 static GtkWidget	*gtkW_hbox_new (GtkWidget *parent);
-static void	gtkW_message_dialog (gint gtk_was_initialized, guchar *message);
-static GtkWidget	*gtkW_message_dialog_new (guchar * name);
+static void	gtkW_message_dialog (gint gtk_was_initialized, gchar *message);
+static GtkWidget	*gtkW_message_dialog_new (gchar * name);
 static GtkWidget	*gtkW_table_add_button (GtkWidget	*table,
 						gchar		*name,
 						gint		x0,
@@ -179,7 +187,7 @@ static GtkWidget	*gtkW_table_add_iscale_entry (GtkWidget	*table,
 						      gdouble	step,
 						      gpointer	table_entry);
 static GtkWidget	 *gtkW_table_add_menu (GtkWidget	*parent,
-					       guchar		*name,
+					       gchar		*name,
 					       gint		x,
 					       gint		y,
 					       GtkSignalFunc	imenu_update,
@@ -188,7 +196,7 @@ static GtkWidget	 *gtkW_table_add_menu (GtkWidget	*parent,
 					       gint		item_num,
 					       gpointer		table_entry);
 static GtkWidget	*gtkW_table_add_toggle (GtkWidget	*table,
-						guchar		*name,
+						gchar		*name,
 						gint		x,
 						gint		y,
 						GtkSignalFunc	update,
@@ -196,7 +204,7 @@ static GtkWidget	*gtkW_table_add_toggle (GtkWidget	*table,
 						gpointer	widget_entry);
 static GtkWidget	*gtkW_table_new (GtkWidget *parent, gint col, gint row);
 static GtkWidget	*gtkW_vbox_add_button (GtkWidget	*vbox,
-					       guchar		*name,
+					       gchar		*name,
 					       GtkSignalFunc	update,
 					       gpointer		data);
 static GtkWidget	*gtkW_vbox_new (GtkWidget *parent);
@@ -343,7 +351,7 @@ typedef struct
   gint	scale;
   gint	start_offset;
   gint	seed;
-  guchar last_file_name[256];
+  gchar last_file_name[256];
 } ValueType;
 
 static ValueType VALS =
@@ -397,10 +405,10 @@ static void	hsv_to_rgb (int *h, int *s, int *v);
 static gdouble	logistic_function (CML_PARAM *param, gdouble x, gdouble power);
 static gint	DIALOG ();
 static GtkWidget *CML_dialog_sub_panel_new (GtkWidget *parent,
-					    guchar *name,
+					    gchar *name,
 					    CML_PARAM *param,
 					    gint channel_id);
-static GtkWidget *CML_dialog_advanced_panel_new (GtkWidget *parent, guchar *name);
+static GtkWidget *CML_dialog_advanced_panel_new (GtkWidget *parent, gchar *name);
 void	preview_update ();
 static void	function_graph_new (GtkWidget *widget, gpointer data);
 static void	CML_set_or_randomize_seed_callback (GtkWidget *widget, gpointer data);
@@ -415,7 +423,7 @@ static gint	force_overwrite (char *filename);
 static void	CML_overwrite_ok_callback (GtkWidget *widget, gpointer   data);
 static void	CML_preview_update_callback (GtkWidget *widget, gpointer   data);
 static void	CML_load_from_file_callback (GtkWidget *widget, gpointer client_data);
-static gint	CML_load_parameter_file (guchar *filename, gint interactive_mode);
+static gint	CML_load_parameter_file (gchar *filename, gint interactive_mode);
 static void	CML_execute_load_from_file (GtkWidget *widget, gpointer client_data);
 static gint	parse_line_to_gint (FILE *file, gint *flag);
 static gdouble	parse_line_to_gdouble (FILE *file, gint *flag);
@@ -460,7 +468,7 @@ gint		mem_chank1_size = 0;
 guchar		*mem_chank2 = NULL;
 gint		mem_chank2_size = 0;
 
-MAIN ();
+MAIN ()
 
 static void
 query ()
@@ -524,7 +532,7 @@ run (char	*name,
       break;
     case RUN_NONINTERACTIVE:
       {
-	guchar *filename = param[3].data.d_string;
+	gchar *filename = param[3].data.d_string;
 
 	if (! CML_load_parameter_file (filename, FALSE))
 	  return;
@@ -1616,7 +1624,7 @@ DIALOG ()
 
 static GtkWidget *
 CML_dialog_sub_panel_new (GtkWidget	*parent,
-			  guchar	*name,
+			  gchar	*name,
 			  CML_PARAM	*param,
 			  gint		channel_id)
 {
@@ -1729,7 +1737,7 @@ CML_dialog_sub_panel_new (GtkWidget	*parent,
 }
 
 static GtkWidget *
-CML_dialog_advanced_panel_new (GtkWidget *parent, guchar *name)
+CML_dialog_advanced_panel_new (GtkWidget *parent, gchar *name)
 {
   GtkWidget	*frame;
   GtkWidget	*subframe;
@@ -1738,7 +1746,7 @@ CML_dialog_advanced_panel_new (GtkWidget *parent, guchar *name)
   gint		index = 0;
   gint		widget_offset = 12;
   gint		channel_id;
-  guchar	*ch_name[] = { "Hue", "Saturation", "Value" };
+  gchar	*ch_name[] = { "Hue", "Saturation", "Value" };
   CML_PARAM	*param;
 
   frame = gtkW_frame_new (parent, name);
@@ -1909,9 +1917,9 @@ CML_copy_parameters_callback (GtkWidget *widget, gpointer data)
       gdk_flush ();
       return;
     }
-  bcopy (channel_menu[copy_source].data,
-	 channel_menu[copy_destination].data,
-	 sizeof (CML_PARAM));
+  memcpy (channel_menu[copy_destination].data,
+	  channel_menu[copy_source].data,
+	  sizeof (CML_PARAM));
   CML_preview_defer = TRUE;
   widgets = widget_pointers[copy_destination];
   for (index = 0; index < CML_PARAM_NUM; index++)
@@ -2076,6 +2084,7 @@ CML_execute_save_to_file (GtkWidget *widget, gpointer client_data)
 	  return;
 	}
       else if (buf.st_mode & S_IFREG) /* already exists */
+	{
 #ifdef	VERBOSE_DIALOGS
 	if (! force_overwrite (filename))
 	  return;
@@ -2084,10 +2093,11 @@ CML_execute_save_to_file (GtkWidget *widget, gpointer client_data)
 #else
       file = fopen (filename, "w");
 #endif
+	}
     }
   if ((err != 0) && (file == NULL))
     {
-      guchar buffer[CML_LINE_SIZE];
+      gchar buffer[CML_LINE_SIZE];
 
       sprintf (buffer, "Error: could not open \"%s\"", filename);
       gtkW_message_dialog (TRUE, buffer);
@@ -2132,7 +2142,7 @@ CML_execute_save_to_file (GtkWidget *widget, gpointer client_data)
       fclose(file);
 #ifdef	VERBOSE_DIALOGS
       {
-	guchar buffer[CML_LINE_SIZE];
+	gchar buffer[CML_LINE_SIZE];
 
 	sprintf (buffer, "Parameters were saved to \"%s\"", filename);
 	gtkW_message_dialog (TRUE, buffer);
@@ -2262,7 +2272,7 @@ CML_execute_load_from_file (GtkWidget *widget, gpointer client_data)
 }
 
 static gint
-CML_load_parameter_file (guchar *filename, gint interactive_mode)
+CML_load_parameter_file (gchar *filename, gint interactive_mode)
 {
   FILE	*file;
   int	channel_id;
@@ -2278,7 +2288,7 @@ CML_load_parameter_file (guchar *filename, gint interactive_mode)
 
   if (!file)
     {
-      guchar buffer[CML_LINE_SIZE];
+      gchar buffer[CML_LINE_SIZE];
 
       if (interactive_mode)
 	{
@@ -2289,7 +2299,7 @@ CML_load_parameter_file (guchar *filename, gint interactive_mode)
     }
   else
     {
-      guchar line[CML_LINE_SIZE];
+      gchar line[CML_LINE_SIZE];
       gdouble version = 0.99;
 
       version = parse_line_to_gdouble (file, &flag); /* old format returns 1 */
@@ -2381,9 +2391,9 @@ CML_load_parameter_file (guchar *filename, gint interactive_mode)
     {
       if ((selective_load_source == 0) || (selective_load_destination == 0))
 	{
-	  bcopy ((void *)&ch[0], &(VALS.hue), sizeof (CML_PARAM));
-	  bcopy ((void *)&ch[1], &(VALS.sat), sizeof (CML_PARAM));
-	  bcopy ((void *)&ch[2], &(VALS.val), sizeof (CML_PARAM));
+	  memcpy (&(VALS.hue), (void *)&ch[0], sizeof (CML_PARAM));
+	  memcpy (&(VALS.sat), (void *)&ch[1], sizeof (CML_PARAM));
+	  memcpy (&(VALS.val), (void *)&ch[2], sizeof (CML_PARAM));
 	  VALS.initial_value = initial_value;
 	  VALS.scale = scale;
 	  VALS.start_offset = start_offset;
@@ -2391,9 +2401,9 @@ CML_load_parameter_file (guchar *filename, gint interactive_mode)
 	}
       else
 	{
-	  bcopy ((void *)&ch[selective_load_source - 1],
-		 (CML_PARAM *)&VALS + (selective_load_destination - 1),
-		 sizeof (CML_PARAM));
+	  memcpy ((CML_PARAM *)&VALS + (selective_load_destination - 1),
+		  (void *)&ch[selective_load_source - 1],
+		  sizeof (CML_PARAM));
 	}
 
       if ( sizeof (VALS.last_file_name) <= strlen (filename))
@@ -2406,8 +2416,8 @@ CML_load_parameter_file (guchar *filename, gint interactive_mode)
 static gint
 parse_line_to_gint (FILE *file, gint *flag)
 {
-  guchar line[CML_LINE_SIZE];
-  guchar *str;
+  gchar line[CML_LINE_SIZE];
+  gchar *str;
   gint	value;
 
   if (! *flag)
@@ -2434,8 +2444,8 @@ parse_line_to_gint (FILE *file, gint *flag)
 static gdouble
 parse_line_to_gdouble (FILE *file, gint *flag)
 {
-  guchar line[CML_LINE_SIZE];
-  guchar *str;
+  gchar line[CML_LINE_SIZE];
+  gchar *str;
   gdouble value;
 
   if (! *flag)
@@ -2632,7 +2642,7 @@ gtkW_toggle_change_value (gtkW_widget_table *wtable)
 
 GtkWidget *
 gtkW_check_button_new (GtkWidget	*parent,
-		       guchar		*name,
+		       gchar		*name,
 		       GtkSignalFunc	update,
 		       gint		*value)
 {
@@ -2649,7 +2659,7 @@ gtkW_check_button_new (GtkWidget	*parent,
 }
 
 static GtkWidget *
-gtkW_dialog_new (guchar		*name,
+gtkW_dialog_new (gchar		*name,
 		 GtkSignalFunc	ok_callback,
 		 GtkSignalFunc	close_callback)
 {
@@ -2685,7 +2695,7 @@ gtkW_dialog_new (guchar		*name,
 
 static GtkWidget *
 gtkW_frame_new (GtkWidget	*parent,
-		guchar		*name)
+		gchar		*name)
 {
   GtkWidget *frame;
 
@@ -2714,7 +2724,7 @@ gtkW_hbox_new (GtkWidget *parent)
 }
 
 static void
-gtkW_message_dialog (gint gtk_was_initialized, guchar *message)
+gtkW_message_dialog (gint gtk_was_initialized, gchar *message)
 {
   GtkWidget *dlg;
   GtkWidget *table;
@@ -2747,7 +2757,7 @@ gtkW_message_dialog (gint gtk_was_initialized, guchar *message)
 }
 
 static GtkWidget *
-gtkW_message_dialog_new (guchar * name)
+gtkW_message_dialog_new (gchar * name)
 {
   GtkWidget *dlg, *button;
 
@@ -2807,7 +2817,7 @@ gtkW_table_add_dscale_entry (GtkWidget		*table,
 {
   GtkObject *adjustment;
   GtkWidget *label, *hbox, *scale, *entry;
-  guchar *buffer;
+  gchar *buffer;
 
   label = gtk_label_new (name);
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -2839,7 +2849,7 @@ gtkW_table_add_dscale_entry (GtkWidget		*table,
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
   gtk_widget_set_usize (entry, GTKW_ENTRY_WIDTH, 0);
 
-  buffer = (guchar *) g_malloc (GTKW_ENTRY_BUFFER_SIZE);
+  buffer = (gchar *) g_malloc (GTKW_ENTRY_BUFFER_SIZE);
   sprintf (buffer, "%6f", *value);
   gtk_entry_set_text (GTK_ENTRY (entry), buffer);
   gtk_signal_connect (GTK_OBJECT (entry), "changed",
@@ -2876,7 +2886,7 @@ gtkW_table_add_iscale_entry (GtkWidget		*table,
 {
   GtkObject *adjustment;
   GtkWidget *label, *hbox, *scale, *entry;
-  guchar *buffer;
+  gchar *buffer;
 
   label = gtk_label_new (name);
   gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
@@ -2907,7 +2917,7 @@ gtkW_table_add_iscale_entry (GtkWidget		*table,
   gtk_object_set_user_data (adjustment, entry);
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
   gtk_widget_set_usize (entry, GTKW_ENTRY_WIDTH, 0);
-  buffer = (guchar *) g_malloc (GTKW_ENTRY_BUFFER_SIZE);
+  buffer = (gchar *) g_malloc (GTKW_ENTRY_BUFFER_SIZE);
   sprintf (buffer, "%d", *value);
   gtk_entry_set_text (GTK_ENTRY (entry), buffer);
   gtk_signal_connect (GTK_OBJECT (entry), "changed",
@@ -2931,7 +2941,7 @@ gtkW_table_add_iscale_entry (GtkWidget		*table,
 
 static GtkWidget *
 gtkW_table_add_menu (GtkWidget		*table,
-		     guchar		*name,
+		     gchar		*name,
 		     gint		x,
 		     gint		y,
 		     GtkSignalFunc	menu_update,
@@ -2991,7 +3001,7 @@ gtkW_table_add_menu (GtkWidget		*table,
 
 static GtkWidget *
 gtkW_table_add_toggle (GtkWidget	*table,
-		       guchar		*name,
+		       gchar		*name,
 		       gint		x,
 		       gint		y,
 		       GtkSignalFunc	update,
@@ -3037,7 +3047,7 @@ gtkW_table_new (GtkWidget *parent, gint col, gint row)
 
 static GtkWidget *
 gtkW_vbox_add_button (GtkWidget		*vbox,
-		      guchar		*name,
+		      gchar		*name,
 		      GtkSignalFunc	update,
 		      gpointer		data)
 {
