@@ -1,7 +1,7 @@
 /*
- * Animation Optimizer plug-in version 0.60.0
+ * Animation Optimizer plug-in version 0.61.0
  *
- * by Adam D. Moss, 1997
+ * by Adam D. Moss, 1997-98
  *     adam@gimp.org
  *     adam@foxbox.org
  *
@@ -11,6 +11,9 @@
 /*
  * REVISION HISTORY:
  *
+ * 98.03.16 : version 0.61.0
+ *            Support more rare opaque/transparent combinations.
+ *
  * 97.12.09 : version 0.60.0
  *            Added support for INDEXED* and GRAY* images.
  *
@@ -63,21 +66,13 @@ static void run(char *name,
 		GParam ** return_vals);
 
 static        void do_optimizations   (void);
-static         int parse_ms_tag       (char *str);
+/*static         int parse_ms_tag       (char *str);*/
 static DisposeType parse_disposal_tag (char *str);
 
 static void window_close_callback  (GtkWidget *widget,
 				    gpointer   data);
-static void playstop_callback  (GtkWidget *widget,
-				gpointer   data);
-static void rewind_callback  (GtkWidget *widget,
-			      gpointer   data);
-static void step_callback  (GtkWidget *widget,
-			    gpointer   data);
 
 static DisposeType  get_frame_disposal  (guint whichframe);
-static void         render_frame        (gint32 whichframe);
-static void         show_frame          (void);
 
 
 GPlugInInfo PLUG_IN_INFO =
@@ -173,6 +168,7 @@ static void run(char *name, int n_params, GParam * param, int *nreturn_vals,
 }
 
 
+#if 0 /* function is presently not used */
 
 static int
 parse_ms_tag (char *str)
@@ -209,6 +205,7 @@ parse_ms_tag (char *str)
   return (sum);
 }
 
+#endif /* parse_ms_tag */
 
 static DisposeType
 parse_disposal_tag (char *str)
@@ -231,7 +228,7 @@ parse_disposal_tag (char *str)
 }
 
 
-
+#if 0 /* function is presently unused */
 
 static void
 build_dialog(GImageType basetype,
@@ -375,6 +372,7 @@ build_dialog(GImageType basetype,
   gtk_widget_show(dlg);
 }
 
+#endif /* build_dialog */
 
 
 /* Rendering Functions */
@@ -594,9 +592,26 @@ do_optimizations(void)
 	      else
 		{
 		  /* RGB no alpha, diff size */
-		  /* SHOULDN'T OCCUR - GIMP doesn't let you have
-		   *  non-alpha layers, except for the bottom one
-		   */
+	      
+		  destptr = this_frame;
+		  srcptr = rawframe;
+	      
+		  for (j=rawy; j<rawheight+rawy; j++)
+		    {
+		      for (i=rawx; i<rawwidth+rawx; i++)
+			{
+			  if ((i>=0 && i<width) &&
+			      (j>=0 && j<height))
+			    {
+			      this_frame[(j*width+i)*4   ] = *(srcptr);
+			      this_frame[(j*width+i)*4 +1] = *(srcptr+1);
+			      this_frame[(j*width+i)*4 +2] = *(srcptr+2);
+			      this_frame[(j*width+i)*4 +3] = 255;
+			    }
+		      
+			  srcptr += 3;
+			}
+		    }
 		}
 	    }
 	  break; /* case RGB */
@@ -682,9 +697,25 @@ do_optimizations(void)
 	      else
 		{
 		  /* I, no alpha, diff size */
-		  /* SHOULDN'T OCCUR - GIMP doesn't let you have
-		   *  non-alpha layers, except for the bottom one
-		   */
+	      
+		  srcptr = rawframe;
+	      
+		  for (j=rawy; j<rawheight+rawy; j++)
+		    {
+		      for (i=rawx; i<rawwidth+rawx; i++)
+			{
+			  if ((i>=0 && i<width) &&
+			      (j>=0 && j<height))
+			    {
+			      this_frame[(j*width+i)*pixelstep]
+				= *srcptr;
+			      this_frame[(j*width+i)*pixelstep
+					+ pixelstep - 1] = 255;
+			    }
+		      
+			  srcptr ++;
+			}
+		    }
 		}
 	    }
 	  break; /* case INDEXED/GRAY */
@@ -914,6 +945,8 @@ do_optimizations(void)
 
 /* Util. */
 
+#if 0    /* function is presently unused */
+
 static guint32
 get_frame_duration (guint whichframe)
 {
@@ -930,6 +963,7 @@ get_frame_duration (guint whichframe)
   return ((guint32) duration);
 }
 
+#endif /* get_frame_duration */
 
 static DisposeType
 get_frame_disposal (guint whichframe)
