@@ -64,7 +64,7 @@ GPlugInInfo PLUG_IN_INFO =
   run,     /* run_proc */
 };
 
-MAIN ();
+MAIN ()
 
 static void
 query ()
