@@ -51,7 +51,7 @@
 #include "libgimp/gimpui.h"
 
 #ifdef RCSID
-static char rcsid[] = "$Id: edge.c,v 1.2 1998/01/09 09:26:11 yosh Exp $";
+static char rcsid[] = "$Id: edge.c,v 1.3 1998/02/01 01:58:46 adrian Exp $";
 #endif
 
 /* Some useful macros */
@@ -225,7 +225,8 @@ run (gchar  *name,
       break;
     }
 
-  if (status == STATUS_SUCCESS)
+  /* make sure the drawable exist and is not indexed */
+  if (gimp_drawable_color (drawable->id) || gimp_drawable_gray (drawable->id))
     {
       gimp_progress_init ("Edge detection...");
 
@@ -242,6 +243,11 @@ run (gchar  *name,
       if (run_mode == RUN_INTERACTIVE)
 	gimp_set_data ("plug_in_edge", &evals, sizeof (EdgeVals));
     }
+  else
+     {
+      /* gimp_message ("edge: cannot operate on indexed color images"); */
+      status = STATUS_EXECUTION_ERROR;
+    }
 
   values[0].data.d_status = status;
 
