@@ -58,7 +58,7 @@ GPlugInInfo PLUG_IN_INFO = {
   run    /*   run_proc */
 };
 
-MAIN();
+MAIN()
 
 /******************************************************************************/
 
