@@ -1,7 +1,7 @@
 /*
  * file: hot/hot.c
  *
- * $Id: hot.c,v 1.5 1998/03/19 02:11:25 adrian Exp $
+ * $Id: hot.c,v 1.7 1998/03/22 20:44:22 adrian Exp $
  */
 
 /*
@@ -94,12 +94,12 @@ struct piArgs {
 typedef enum {
   act_lredux = 0,
   act_sredux = 1,
-  act_flag = 2,
+  act_flag = 2
 } hotAction;
 
 typedef enum {
   mode_ntsc = 0,
-  mode_pal = 1,
+  mode_pal = 1
 } hotModes;
 
 #define	CHROMA_LIM      50.0		/* chroma amplitude limit */
@@ -228,7 +228,6 @@ run(char *name, int nparam, GParam *param,
   *nretvals = 1;
   *retvals = rvals;
 
-  /* bzero(&args, sizeof(struct piArgs)); */
   memset(&args,(int)0,sizeof(struct piArgs));
   args.mode=-1;
 
