@@ -40,6 +40,10 @@
 #include "gtk/gtk.h"
 #include "libgimp/gimp.h"
 
+#ifndef M_PI
+#define M_PI    3.14159265358979323846
+#endif /* M_PI */
+
 #define MAX_PREVIEW_WIDTH 256
 #define MAX_PREVIEW_HEIGHT 256
 #define MAX_DEFORM_AREA_RADIUS 100
@@ -211,7 +215,7 @@ static int frame_number;
 static int layer_alpha;
 
 
-MAIN ();
+MAIN ()
 
 static void
 query ()
@@ -588,7 +592,7 @@ iwarp_layer_copy(gint32 layerID)
                                   
 
 
-void iwarp()
+static void iwarp()
 {
  int i;
  gint32 layerID;
