@@ -50,6 +50,9 @@
 #include <gtk/gtk.h>
 #include <libgimp/gimp.h>
 
+#ifndef M_PI
+#define M_PI    3.14159265358979323846
+#endif /* M_PI */
 
 #define PLUG_IN_NAME 	"plug_in_mblur"
 #define PLUG_IN_VERSION	"Sep 1997, 1.2"
@@ -101,7 +104,7 @@ static void    dialog_help_callback(GtkWidget *, gpointer);
 static void    dialog_scale_update(GtkAdjustment *, gint32 *);
 static void    dialog_toggle_update(GtkWidget *, gint32);
 
-static gint 		mblur_dialog(void);
+static gboolean		mblur_dialog(void);
 /***** Variables *****/
 
 GPlugInInfo PLUG_IN_INFO = {
@@ -117,7 +120,7 @@ static mblur_vals_t mbvals = {
 	45		/* radius */
 }; /* mb_vals */
 
-static mb_run= FALSE;
+static gboolean mb_run = FALSE;
 
 static GDrawable *drawable;
 
@@ -718,7 +721,7 @@ pixel_fetcher_destroy(pixel_fetcher_t *pf)
  *
  ****************************************/
 
-static gint
+static gboolean
 mblur_dialog(void)
 {
   GtkWidget	*dialog;
