@@ -58,7 +58,7 @@
 #include "libgimp/gimp.h"
 
 #ifdef RCSID
-static char rcsid[] = "$Id: nova.c,v 1.3 1998/03/18 23:40:44 yosh Exp $";
+static char rcsid[] = "$Id: nova.c,v 1.4 1998/03/25 02:17:24 yosh Exp $";
 #endif
 
 
@@ -69,6 +69,10 @@ static char rcsid[] = "$Id: nova.c,v 1.3 1998/03/18 23:40:44 yosh Exp $";
 #define M_PI    3.14159265358979323846
 #endif /* M_PI */
 
+#ifndef RAND_MAX
+#define RAND_MAX 2147483647
+#endif /* RAND_MAX */
+
 #if 0
 #define DEBUG1 printf
 #else
