@@ -18,10 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: oilify.c,v 1.2 1998/01/29 05:13:32 sopwith Exp $
+ * $Id: oilify.c,v 1.3 1998/03/26 02:08:21 yosh Exp $
  */
 
 #include <stdio.h>
+#include <string.h>
 #include "gtk/gtk.h"
 #include "libgimp/gimp.h"
 
@@ -207,7 +208,7 @@ oilify (GDrawable *drawable)
   gint width, height;
   guchar *src_row, *src;
   guchar *dest_row, *dest;
-  gint x, y, c, b, i, px, xx, yy, n;
+  gint x, y, c, b, xx, yy, n;
   gint x1, y1, x2, y2;
   gint x3, y3, x4, y4;
   gint Val[4];
