@@ -28,6 +28,7 @@
 #include "libgimp/gimpui.h"
 #include "siod.h"
 #include "script-fu-console.h"
+#include <plug-ins/dbbrowser/dbbrowser.h>
 
 #define TEXT_WIDTH  400
 #define TEXT_HEIGHT 400
@@ -157,7 +158,6 @@ script_fu_console_interface ()
   GtkWidget *hbox;
   gchar **argv;
   gint argc;
-  guchar *color_cube;
 
   argc = 1;
   argv = g_new (gchar *, 1);
@@ -166,16 +166,6 @@ script_fu_console_interface ()
   gtk_init (&argc, &argv);
   gtk_rc_parse (gimp_gtkrc ());
 
-  gdk_set_use_xshm(gimp_use_xshm());
-  
-  gtk_preview_set_gamma(gimp_gamma());
-  gtk_preview_set_install_cmap(gimp_install_cmap());
-  color_cube = gimp_color_cube();
-  gtk_preview_set_color_cube(color_cube[0], color_cube[1], color_cube[2], color_cube[3]);
-  
-  gtk_widget_set_default_visual(gtk_preview_get_visual());
-  gtk_widget_set_default_colormap(gtk_preview_get_cmap());
-
   dlg = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (dlg), "Script-Fu Console");
   gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
