@@ -26,6 +26,8 @@
 #include "script-fu-scripts.h"
 #include "script-fu-server.h"
 
+extern FILE *siod_output;
+
 /* External functions
  */
 extern void gimp_extension_process (guint timeout);
@@ -96,7 +98,7 @@ static gint script_fu_base = TRUE;
 extern gint server_mode;
 
 
-MAIN ();
+MAIN ()
 
 static void
 sfquit ()
@@ -163,6 +165,8 @@ run (char    *name,
      int     *nreturn_vals,
      GParam **return_vals)
 {
+  siod_output = stdout;
+
   /*  Determine before we allow scripts to register themselves
    *   whether this is the base, automatically installed script-fu extension
    */
@@ -494,7 +498,7 @@ marshall_proc_db_call (LISP a)
   int success = TRUE;
   LISP color_list;
   LISP intermediate_val;
-  LISP return_val;
+  LISP return_val = NIL;
   char *string;
   int string_len;
   LISP a_saved;
