@@ -6,13 +6,23 @@
 ; of saving animations (i.e. the GIF plugin).
 ;
 
+(define (copy-layer-ripple dest-image dest-drawable source-image source-drawable)
+  (gimp-selection-all dest-image)
+  (gimp-edit-clear dest-image dest-drawable)
+  (gimp-selection-none dest-image)
+  (gimp-selection-all source-image)
+  (gimp-edit-copy source-image source-drawable)
+  (gimp-selection-none source-image)
+      (let ((floating-sel (car (gimp-edit-paste dest-image dest-drawable FALSE))))
+	(gimp-floating-sel-anchor floating-sel)))
+
 (define (script-fu-ripply-anim img drawable displacement num-frames)
   (let* ((width (car (gimp-drawable-width drawable)))
 	 (height (car (gimp-drawable-height drawable)))
 	 (ripple-image (car (gimp-image-new width height GRAY)))
 	 (ripple-layer (car (gimp-layer-new ripple-image width height GRAY_IMAGE "Ripple Texture" 100 NORMAL))))
 
-; this script generates its own displacement map
+ ; this script generates its own displacement map
 
     (gimp-image-disable-undo ripple-image)
     (gimp-palette-set-background '(127 127 127) )
@@ -44,33 +54,40 @@
     (set! xoffset (/ width num-frames))
     (set! yoffset (/ height num-frames))
 
-    (set! out-imagestack (car (gimp-image-new width height RGB)))
-    (gimp-image-disable-undo out-imagestack)
+    (let* ((out-imagestack (car (gimp-image-new width height RGB))))
 
-    (while (> remaining-frames 0)
-	   (set! dup-image (car (gimp-channel-ops-duplicate rippletiled-image)))
-	   (gimp-crop dup-image width height xpos ypos)
-
-	   (set! this-layer (car (gimp-layer-copy drawable TRUE)))
-	   (gimp-image-add-layer out-imagestack this-layer 0)
-
-	   (set! dup-layer (car (gimp-image-get-active-layer dup-image)))
-	   (plug-in-displace 1 out-imagestack this-layer displacement displacement TRUE TRUE dup-layer dup-layer 2)
-
-	   (gimp-image-enable-undo dup-image)
-	   (gimp-image-delete dup-image)
-
-	   (set! remaining-frames (- remaining-frames 1))
-	   (set! xpos (+ xoffset xpos))
-	   (set! ypos (+ yoffset ypos)))
-
-    (gimp-image-enable-undo rippletiled-image)
-    (gimp-image-delete rippletiled-image)
-
-    (gimp-image-enable-undo out-imagestack)
-    (gimp-display-new out-imagestack)
-
-    (gimp-displays-flush)))
+      (gimp-image-disable-undo out-imagestack)
+      
+      (while (> remaining-frames 0)
+	     (set! dup-image (car (gimp-channel-ops-duplicate rippletiled-image)))
+	     (gimp-image-disable-undo dup-image)
+	     (gimp-crop dup-image width height xpos ypos)
+	     
+	     (set! layer-name (string-append "Frame " 
+			(number->string (- num-frames remaining-frames) 10)))     
+	     (set! this-layer (car (gimp-layer-new out-imagestack 
+						   width height RGB 
+						   layer-name 100 NORMAL)))
+	     (gimp-image-add-layer out-imagestack this-layer 0)
+	     
+	     (copy-layer-ripple out-imagestack this-layer img drawable)
+	     
+	     (set! dup-layer (car (gimp-image-get-active-layer dup-image)))
+	     (plug-in-displace 1 out-imagestack this-layer 
+			       displacement displacement 
+			       TRUE TRUE dup-layer dup-layer 2)
+	     
+	     (gimp-image-enable-undo dup-image)
+	     (gimp-image-delete dup-image)
+	     
+	     (set! remaining-frames (- remaining-frames 1))
+	     (set! xpos (+ xoffset xpos))
+	     (set! ypos (+ yoffset ypos)))
+      
+      (gimp-image-enable-undo rippletiled-image)
+      (gimp-image-delete rippletiled-image)
+      (gimp-image-enable-undo out-imagestack)
+      (gimp-display-new out-imagestack))))
 
 (script-fu-register "script-fu-ripply-anim"
 		    "<Image>/Script-Fu/Animators/Rippling"
