@@ -1,5 +1,5 @@
 /*
- * "$Id: sgi.h,v 1.1.1.1 1997/11/24 22:04:37 sopwith Exp $"
+ * "$Id: sgi.h,v 1.3 1998/03/26 02:08:30 yosh Exp $"
  *
  *   SGI image file format library definitions.
  *
@@ -22,6 +22,35 @@
  * Revision History:
  *
  *   $Log: sgi.h,v $
+ *   Revision 1.3  1998/03/26 02:08:30  yosh
+ *   * applied gimp-quinet-980122-0 and tweaked the tests a bit, this makes the
+ *   optional library tests in configure.
+ *
+ *   * applied gimp-jbuhler-980321-0, fixes more warnings in plug-ins
+ *
+ *   -Yosh
+ *
+ *   Revision 1.2  1998/03/25 02:17:34  yosh
+ *   * configure.in: corrected test for libXmu for some systems; added test for
+ *   difftime
+ *
+ *   * app/main.c: use glib ATEXIT macro
+ *
+ *   * app/text_tool.c: applied gimp-stric-980321-0 (text preview refresh)
+ *
+ *   * plug-ins/script-fu/script-fu-console.c: don't need to init gtkpreview stuff,
+ *   since we don't use them
+ *
+ *   * plug-ins/script-fu/: many portability fixes
+ *
+ *   * plug-ins/pnm/pnm.c: sprintf portability patch
+ *
+ *   * plug-ins now #define RAND_MAX if needed
+ *
+ *   * plug-ins/sparkle/sparkle.c: applied gimp-joke-980322-1
+ *
+ *   -Yosh
+ *
  *   Revision 1.1.1.1  1997/11/24 22:04:37  sopwith
  *   Let's try this import one last time.
  *
@@ -51,6 +80,8 @@
 
 #  include <stdio.h>
 #  include <stdlib.h>
+#  include <unistd.h>
+#  include <string.h>
 
 #  ifdef __cplusplus
 extern "C" {
@@ -110,5 +141,5 @@ extern int	sgiPutRow(sgi_t *sgip, short *row, int y, int z);
 #endif /* !_SGI_H_ */
 
 /*
- * End of "$Id: sgi.h,v 1.1.1.1 1997/11/24 22:04:37 sopwith Exp $".
+ * End of "$Id: sgi.h,v 1.3 1998/03/26 02:08:30 yosh Exp $".
  */
