@@ -1,5 +1,5 @@
 /*
- * "$Id: sgilib.c,v 1.1.1.1 1997/11/24 22:04:37 sopwith Exp $"
+ * "$Id: sgilib.c,v 1.2 1998/03/26 02:08:31 yosh Exp $"
  *
  *   SGI image file format library routines.
  *
@@ -37,6 +37,14 @@
  * Revision History:
  *
  *   $Log: sgilib.c,v $
+ *   Revision 1.2  1998/03/26 02:08:31  yosh
+ *   * applied gimp-quinet-980122-0 and tweaked the tests a bit, this makes the
+ *   optional library tests in configure.
+ *
+ *   * applied gimp-jbuhler-980321-0, fixes more warnings in plug-ins
+ *
+ *   -Yosh
+ *
  *   Revision 1.1.1.1  1997/11/24 22:04:37  sopwith
  *   Let's try this import one last time.
  *
@@ -67,6 +75,10 @@
  *   Initial revision
  */
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include "sgi.h"
 
 
@@ -870,5 +882,5 @@ write_rle16(FILE  *fp,	/* I - File to write to */
 
 
 /*
- * End of "$Id: sgilib.c,v 1.1.1.1 1997/11/24 22:04:37 sopwith Exp $".
+ * End of "$Id: sgilib.c,v 1.2 1998/03/26 02:08:31 yosh Exp $".
  */
