@@ -60,6 +60,10 @@
 #define M_PI    3.14159265358979323846
 #endif /* M_PI */
 
+#ifndef M_PI_2
+#define M_PI_2  1.57079632679489661923
+#endif /* M_PI_2 */
+
 #define PLUG_IN_NAME    "plug_in_whirl_pinch"
 #define PLUG_IN_VERSION "May 1997, 2.09"
 
